Crate tpl_mutex
tpl_
mutex
2.0.0
All Items
Crate Items
Structs
Crate
tpl_
mutex
Structs

TplMutex
Type use for mutual exclusion of data across Tpl (task priority level)
TplMutex
Guard
RAII implementation of a
TplMutex
lock. When this structure is dropped, the lock will be unlocked.